function [PDFfill,mu,sd] = get_PDFandGaussianFit_v2_shel(bin,hist,x_limit,x_tick)
%GET_PDFANDGAUSSIANFIT calculates and plots the probability density function using the
%given histogram (does not have to be normalised)
%%%%%%%%%%%%%%%%INPUTS:%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% x       bin centres for histogram (row vector)
% hist    histogram (row vector, same size as x)
% x_limit x-axis limits (e.g. [0 150])
% x_tick  x_axis ticks (e.g. 0:50:200)
%%%%%%%%%%%%%%%%OUTPUTS:%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PDF   probability density function
% mu    average of the fitted normal distribution
% sd    standard deviation of the fitted normal distribution
%%%%%%%Functions required:%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%1. get_PDFfromHistogram_v1
%2. get_stdMomentFromPDF_v1
%3. plot_PDFandFit_v1
%%Change log:%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% v2:
% - assumes bins should be uniformly spaced with a spacing given by
%   min(bin). If a bin centre is not present in bins, fills hist with 0 value
%%%%%%%%%%%%%%%%%%%version 14-03-2024p.m.%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if size(bin,2)>1
    error('x must be a row vector');
end
if ~isequal(size(hist),size(bin))
    error('x and hist must have the same size');
end

%if bins are not equally spaced, then fill the bins in-between with 0
dbin = min(diff(bin));
binfill = (min(bin)-dbin):dbin:(max(bin)+dbin);
histfill = zeros(size(binfill));
for k = 1:length(bin)
    [~,idBinFill] = ismember(bin(k),binfill);    %index of new bin
    if idBinFill == 0
        error(['bin ' num2str(bin(k)) ' not found in uniformly spaced bin']);
    else
        histfill(idBinFill) = hist(k);
    end
end

%first normalise to probability density function (pdf)
PDFfill = get_PDFfromHistogram_v1(histfill,binfill);

%get standard deviation and mean from pdf as initial guesses for fitting
[~,sigma,avg] = get_stdMomentFromPDF_v1(binfill,PDFfill,1);

norm_fun = @(mu, sd, x) 1/(sqrt(2*pi)*sd)*exp(-(x-mu).^2/(2*sd^2));
[sol, f] = lsqcurvefit(@(p, x) norm_fun(p(1), p(2), x), ...
    [avg sigma], binfill, PDFfill);
mu = sol(1);
sd = sol(2);

bin_fit = linspace(floor(min(binfill)./2),1.5.*max(binfill),3000);

plot_PDFandFit_v1_shel(binfill,PDFfill,bin_fit, norm_fun(mu, sd, bin_fit),x_limit,x_tick);

end
