%PLOT_DROPLETSIZE plots the Fig. 5(a-b) and 10c
clearvars

mainDir = '.';

date = 20231128;

isSatIncluded = false;     %include satellite droplets? (if not, set satThres)

%% load data
statName = 'statistics_v3.mat';
radiiLRName = 'radii_cap_all_v3.dat';

%Pressure runs
type = 1;
directory = get_dropletDirectory_v01(date,type);

meanRAll = nan(size(directory));
stdRAll = meanRAll;
meanRAll_vol = nan(size(directory));
stdRAll_vol = meanRAll;
pressShell = meanRAll;
pressCont = meanRAll;

meanR_LR = nan(length(directory),2);    %[left right] radii
stdR_LR = meanR_LR;
meanR_LR_vol = meanR_LR;
stdR_LR_vol = meanR_LR;

for j = 3:length(directory)
    curStat = load([mainDir directory{j} 'analysisImage/Split/' statName],...
        'meanValue','stdValue','meanValue_vol','stdValue_vol');
    meanRAll(j) = curStat.meanValue;
    stdRAll(j) = curStat.stdValue;
    meanRAll_vol(j) = curStat.meanValue_vol;
    stdRAll_vol(j) = curStat.stdValue_vol;

    press = readmatrix([mainDir directory{j} 'press.txt'],'Delimiter','\t');    %pressure
    
    pressCont(j) = press(2,2);    %psi
    pressShell(j) = press(2,4);   %mbar

    curStat = load([mainDir directory{j} 'analysisImage/Split/' statName],'cf');
    radiiLR = readmatrix([mainDir directory{j} 'analysisImage/Split/' radiiLRName]);
    meanR_LR(j,1) = mean(radiiLR(4,:)).*curStat.cf;
    meanR_LR(j,2) = mean(radiiLR(6,:)).*curStat.cf;
    stdR_LR(j,1) = std(radiiLR(4,:)).*curStat.cf;
    stdR_LR(j,2) = std(radiiLR(6,:)).*curStat.cf;
    
    if ~isSatIncluded
        %filter out satellite droplets
        curStat = load([mainDir directory{j} 'analysisImage/Split/' statName],'satThres','cf');
        radiiLR(2,:) = radiiLR(2,:).*curStat.cf;    %convert to um
        radiiLR(2,radiiLR(2,:)<=curStat.satThres) = nan;
        meanR_noSat(j) = mean(radiiLR(2,:),'omitnan');
        stdR_noSat(j) = std(radiiLR(2,:),'omitnan');
    end
end
clear press curStat

pressCont = pressCont.*68.9475728;    %convert psi to mbar

%% plot data
if ~isSatIncluded
  
    h = [];
    legendName = {};

    figure
    hold on
    ylabel('$R_{drop} (\mu m)$','interpreter','latex')
    xlabel('$P_{disp}/P_{cont}$','interpreter','latex')
    title('Fig. 10C. Fig. 5A: blue data points only')
    grid on
    box on
    j = 3:11;
    h(end+1) = errorbar(pressShell(j)./pressCont(j),meanR_noSat(j),stdR_noSat(j),'ks','MarkerFaceColor','k');
    legendName{end+1} = '$t \sim 1h$';
    j = 12:length(directory);
    h(end+1) = errorbar(pressShell(j)./pressCont(j),meanR_noSat(j),stdR_noSat(j),'bs','MarkerFaceColor','b');
    legendName{end+1} = '$t\sim 5h$';
    legend(h,legendName,'interpreter','latex','location','best')
    
    h = [];
    legendName = {};
    figure
    hold on
    ylabel('PDI','interpreter','latex')
    xlabel('$P_{disp}/P_{cont}$','interpreter','latex')
    title('Fig. 5B')
    grid on
    box on
    j = 12:length(directory);
    h(end+1) = plot(pressShell(j)./pressCont(j),stdR_noSat(j)./meanR_noSat(j),'bs','MarkerFaceColor','b');
end